@@ -1,13 +1,15 @@
 """getgfs - a library for extracting weather forecast variables from the NOAA GFS forecast in a pure python, no obscure dependencies way
 """
-import requests, json, os, re, dateutil.parser, sys
+import requests, json, os, re, dateutil.parser, sys, warnings
 from datetime import datetime, timedelta
 import numpy as np
 from scipy.interpolate import interp1d
 from .decode import *
 
 try:
-    from fuzzywuzzy import fuzz
+    with warnings.catch_warnings():
+        warnings.simplefilter("ignore")
+        from fuzzywuzzy import fuzz
 except:
     pass
 
@@ -341,26 +343,28 @@ class Forecast:
             interpolation object: V component of wind interpolater by altitude
         """
         info = self.get(
-            ["ugrdprs", "vgrdprs", "ugrd2pv", "vgrd2pv", "hgtsfc", "hgtprs"],
+            ["ugrdprs", "vgrdprs", "ugrd10m", "vgrd10m", "hgtsfc", "hgtprs"],
             date_time,
             lat,
             lon,
         )
 
         u_wind = list(info.variables["ugrdprs"].data.flatten()) + list(
-            info.variables["ugrd2pv"].data.flatten()
+            info.variables["ugrd10m"].data.flatten()
         )
         v_wind = list(info.variables["vgrdprs"].data.flatten()) + list(
-            info.variables["vgrd2pv"].data.flatten()
+            info.variables["vgrd10m"].data.flatten()
         )
 
         # at the altitudes we are concerned with the geopotential height and altitude are within 0.5km of eachother
         alts = list(info.variables["hgtprs"].data.flatten()) + list(
-            info.variables["hgtsfc"].data.flatten()
+            info.variables["hgtsfc"].data.flatten() + 10
         )
 
-        return interp1d(alts, u_wind, fill_value="extrapolate"), interp1d(
-            alts, v_wind, fill_value="extrapolate"
+        return interp1d(
+            alts, u_wind, fill_value=(u_wind[-1], u_wind[-2]), bounds_error=False
+        ), interp1d(
+            alts, v_wind, fill_value=(v_wind[-1], v_wind[-2]), bounds_error=False
         )
 
     def __str__(self):
@@ -444,7 +448,7 @@ def get_attributes(res, step):
             url.format(
                 res=res,
                 step=step,
-                date=date.today().strftime("%Y%m%d"),
+                date=(date.today() - timedelta(days=2)).strftime("%Y%m%d"),
                 hour=0,
                 info="dds",
             )
@@ -452,6 +456,11 @@ def get_attributes(res, step):
         if r.status_code != 200:
             raise RuntimeError("The forecast resolution and timestep was not found")
         arrays = re.findall(r"ARRAY:\n(.*?)\n", r.text)
+
+        if len(arrays) == 0:
+            raise RuntimeError(
+                "The forecast datetime was not found, please report as this should no longer occur"
+            )
         for array in arrays:
             var = re.findall(r"(.*?)\[", array)[0].split()[1]
             if var in variables.keys():
